cmake test fixes
diff --git a/googletest/CMakeLists.txt b/googletest/CMakeLists.txt
index 4225b24..af88e6d 100644
--- a/googletest/CMakeLists.txt
+++ b/googletest/CMakeLists.txt
@@ -250,7 +250,7 @@
   # Python tests.
 
   cxx_executable(googletest-break-on-failure-unittest_ test gtest)
-  py_test(gtest_break_on_failure_unittest)
+  py_test(googletest-break-on-failure-unittest)
 
   # Visual Studio .NET 2003 does not support STL with exceptions disabled.
   if (NOT MSVC OR MSVC_VERSION GREATER 1310)  # 1310 is Visual Studio .NET 2003
@@ -266,28 +266,28 @@
     "${cxx_exception}"
     gtest_main
     test/googletest-catch-exceptions-test_.cc)
-  py_test(gtest_catch_exceptions_test)
+  py_test(googletest-catch-exceptions-test)
 
   cxx_executable(googletest-color-test_ test gtest)
-  py_test(gtest_color_test)
+  py_test(googletest-color-test)
 
   cxx_executable(googletest-env-var-test_ test gtest)
-  py_test(gtest_env_var_test)
+  py_test(googletest-env-var-test)
 
   cxx_executable(googletest-filter-unittest_ test gtest)
-  py_test(gtest_filter_unittest)
+  py_test(googletest-filter-unittest)
 
   cxx_executable(gtest_help_test_ test gtest_main)
   py_test(gtest_help_test)
 
   cxx_executable(googletest-list-tests-unittest_ test gtest)
-  py_test(gtest_list_tests_unittest)
+  py_test(googletest-list-tests-unittest)
 
   cxx_executable(googletest-output-test_ test gtest)
-  py_test(gtest_output_test --no_stacktrace_support)
+  py_test(googletest-output-test --no_stacktrace_support)
 
   cxx_executable(googletest-shuffle-test_ test gtest)
-  py_test(gtest_shuffle_test)
+  py_test(googletest-shuffle-test)
 
   # MSVC 7.1 does not support STL with exceptions disabled.
   if (NOT MSVC OR MSVC_VERSION GREATER 1310)
@@ -295,18 +295,18 @@
     set_target_properties(googletest-throw-on-failure-test_
       PROPERTIES
       COMPILE_FLAGS "${cxx_no_exception}")
-    py_test(gtest_throw_on_failure_test)
+    py_test(googletest-throw-on-failure-test)
   endif()
 
   cxx_executable(googletest-uninitialized-test_ test gtest)
-  py_test(gtest_uninitialized_test)
+  py_test(googletest-uninitialized-test)
 
   cxx_executable(gtest_xml_outfile1_test_ test gtest_main)
   cxx_executable(gtest_xml_outfile2_test_ test gtest_main)
   py_test(gtest_xml_outfiles_test)
-  py_test(gtest_json_outfiles_test)
+  py_test(googletest-json-outfiles-test)
 
   cxx_executable(gtest_xml_output_unittest_ test gtest)
   py_test(gtest_xml_output_unittest --no_stacktrace_support)
-  py_test(gtest_json_output_unittest)
+  py_test(googletest-json-output-unittest)
 endif()
diff --git a/googletest/Makefile.am b/googletest/Makefile.am
index 69c2312..b44c841 100644
--- a/googletest/Makefile.am
+++ b/googletest/Makefile.am
@@ -97,19 +97,19 @@
 
 # Python tests that we don't run.
 EXTRA_DIST += \
-  test/gtest_break_on_failure_unittest.py \
-  test/gtest_catch_exceptions_test.py \
-  test/gtest_color_test.py \
-  test/gtest_env_var_test.py \
-  test/gtest_filter_unittest.py \
+  test/googletest-break-on-failure-unittest.py \
+  test/googletest-catch-exceptions-test.py \
+  test/googletest-color-test.py \
+  test/googletest-env-var-test.py \
+  test/googletest-filter-unittest.py \
   test/gtest_help_test.py \
-  test/gtest_list_tests_unittest.py \
-  test/gtest_output_test.py \
-  test/gtest_output_test_golden_lin.txt \
-  test/gtest_shuffle_test.py \
+  test/googletest-list-tests-unittest.py \
+  test/googletest-output-test.py \
+  test/googletest-output-test_golden_lin.txt \
+  test/googletest-shuffle-test.py \
   test/gtest_test_utils.py \
-  test/gtest_throw_on_failure_test.py \
-  test/gtest_uninitialized_test.py \
+  test/googletest-throw-on-failure-test.py \
+  test/googletest-uninitialized-test.py \
   test/gtest_xml_outfiles_test.py \
   test/gtest_xml_output_unittest.py \
   test/gtest_xml_test_utils.py
diff --git a/googletest/test/googletest-catch-exceptions-test_.cc b/googletest/test/googletest-catch-exceptions-test_.cc
index c6d953c..cb018f9 100644
--- a/googletest/test/googletest-catch-exceptions-test_.cc
+++ b/googletest/test/googletest-catch-exceptions-test_.cc
@@ -30,7 +30,7 @@
 // Author: vladl@google.com (Vlad Losev)
 //
 // Tests for Google Test itself. Tests in this file throw C++ or SEH
-// exceptions, and the output is verified by gtest_catch_exceptions_test.py.
+// exceptions, and the output is verified by googletest-catch-exceptions-test.py.
 
 #include "gtest/gtest.h"
 
diff --git a/googletest/test/googletest-output-test_.cc b/googletest/test/googletest-output-test_.cc
index 9ae9dc6..29fc993 100644
--- a/googletest/test/googletest-output-test_.cc
+++ b/googletest/test/googletest-output-test_.cc
@@ -29,7 +29,7 @@
 //
 // The purpose of this file is to generate Google Test output under
 // various conditions.  The output will then be verified by
-// gtest_output_test.py to ensure that Google Test generates the
+// googletest-output-test.py to ensure that Google Test generates the
 // desired messages.  Therefore, most tests in this file are MEANT TO
 // FAIL.
 //
diff --git a/googletest/test/googletest-throw-on-failure-test.py b/googletest/test/googletest-throw-on-failure-test.py
index 7253cfd..26ba32b 100755
--- a/googletest/test/googletest-throw-on-failure-test.py
+++ b/googletest/test/googletest-throw-on-failure-test.py
@@ -76,7 +76,7 @@
 
 
 # The tests.  TODO(wan@google.com): refactor the class to share common
-# logic with code in gtest_break_on_failure_unittest.py.
+# logic with code in googletest-break-on-failure-unittest.py.
 class ThrowOnFailureTest(gtest_test_utils.TestCase):
   """Tests the throw-on-failure mode."""
diff --git a/googletest/test/googletest-catch-exceptions-test.py b/googletest/test/googletest-catch-exceptions-test.py
index d12a32a..cda61b2 100755
--- a/googletest/test/googletest-catch-exceptions-test.py
+++ b/googletest/test/googletest-catch-exceptions-test.py
@@ -30,7 +30,7 @@
 
 """Tests Google Test's exception catching behavior.
 
-This script invokes gtest_catch_exceptions_test_ and
+This script invokes googletest-catch-exceptions-test_ and
 gtest_catch_exceptions_ex_test_ (programs written with
 Google Test) and verifies their output.
 """
@@ -50,7 +50,7 @@
 EX_EXE_PATH = gtest_test_utils.GetTestExecutablePath(
     'googletest_catch_exceptions_ex_test_')
 
 # Path to the gtest_catch_exceptions_test_ binary, compiled with
 # exceptions disabled.
 EXE_PATH = gtest_test_utils.GetTestExecutablePath(
     'googletest_catch_exceptions_no_ex_test_')
@@ -50,7 +50,7 @@
     'googletest_catch_exceptions_ex_test_')
 
-# Path to the gtest_catch_exceptions_test_ binary, compiled with
+# Path to the googletest-catch-exceptions-test_ binary, compiled with
 # exceptions disabled.
 EXE_PATH = gtest_test_utils.GetTestExecutablePath(